/*  VER 006  TAB P  $Id: dummy.c,v 1.1.2.1 2003/01/21 09:43:48 egil Exp $
 *
 *  dummies for some functions in libstorage provides
 *
 *  $Log: dummy.c,v $
 *  Revision 1.1.2.1  2003/01/21 09:43:48  egil
 *  Updated dummy to do SMerrno
 *
 *  Revision 1.1  1999/03/11 08:00:27  src
 *  Moved from storage
 *
 *  Revision 1.1  1999/03/07 14:58:24  src
 *  Storage API supported.
 */

#include "../src/common.h"
#include "dummy.h"

/*
 *  error reporting
 */
int SMerrno = SMERR_NOERROR;
char *SMerrorstr;

/*
 *  token handling
 */
BOOL
IsToken(const char *text)
{
    return FALSE; /* can't be */
}

/*
 *  token handling
 */
TOKEN 
TextToToken(const char *text)
{
    TOKEN t;
    t.dummy = 0;
    return t;
}

/*
 *  called first to initialize
 */
BOOL
SMsetup(SMSETUP type, BOOL *value)
{
    SMinit(); /* error */
    return FALSE;
}

/*
 *  called after SMsetup
 */
BOOL
SMinit(void)
{
    SMerrorstr = "Storage-API not available";
    SMerrno = SMERR_UNINIT;
    return FALSE;
}

/*
 *  retrieve entire article
 */
ARTHANDLE *
SMretrieve(const TOKEN token, const RETRTYPE amount)
{
    SMinit(); /* error */
    return (ARTHANDLE *)0;
}

/*
 *  free up storage following SMretrieve
 */
void
SMfreearticle(ARTHANDLE *article)
{
}

/*
 *  called finally...
 */
void
SMshutdown(void)
{
}
